@@ -13,7 +13,7 @@ require Exporter;
 our @ISA       = qw( Exporter );
 our @EXPORT_OK = qw( debug );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 my $env_prefix = 'DEVEL_SCOPE_';
 my @env_vars_maybe = grep { m|^$env_prefix| } keys %ENV;
@@ -119,11 +119,11 @@ __END__
 
 =head1 NAME
 
-Devel::Scope
+Devel::Scope - Scope based debug
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
